@@ -62,7 +62,9 @@ from neutron_lib.api.definitions import l3
 from neutron_lib.api.definitions import l3_conntrack_helper
 from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
+from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
+from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
@@ -98,6 +100,7 @@ from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
+from neutron_lib.api.definitions import rbac_bgpvpn
 from neutron_lib.api.definitions import rbac_security_groups
 from neutron_lib.api.definitions import rbac_subnetpool
 from neutron_lib.api.definitions import revisionifmatch
@@ -187,7 +190,9 @@ _ALL_API_DEFINITIONS = {
     l3_conntrack_helper,
     l3_ext_gw_mode,
     l3_ext_ha_mode,
+    l3_ext_ndp_proxy,
     l3_flavors,
+    l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
     logging,
     logging_resource,
@@ -223,6 +228,7 @@ _ALL_API_DEFINITIONS = {
     qos_rules_alias,
     rbac_address_groups,
     rbac_address_scope,
+    rbac_bgpvpn,
     rbac_security_groups,
     rbac_subnetpool,
     revisionifmatch,
