@@ -24,6 +24,7 @@ KNOWN_ATTRIBUTES = (
     'device_owner',
     'dns_nameservers',
     'enable_dhcp',
+    'enable_ndp_proxy',
     'fixed_ips',
     'gateway_ip',
     'host_routes',
@@ -110,6 +111,8 @@ KNOWN_EXTENSIONS = (
     'l3-conntrack-helper',
     'l3-ha',
     'l3_agent_scheduler',
+    'l3-ext-ndp-proxy',
+    'l3-ndp-proxy',
     'l3-port-ip-change-not-allowed',
     'logging',
     'metering',
@@ -132,6 +135,7 @@ KNOWN_EXTENSIONS = (
     'quotas',
     'rbac-address-group',
     'rbac-address-scope',
+    'rbac-bgpvpn',
     'rbac-policies',
     'rbac-security-groups',
     'rbac-subnetpool',
